@@ -18,6 +18,7 @@ import subprocess
 import os
 import shutil
 import math
+import tempfile
 
 from pymatgen.io.vaspio.vasp_input import VaspInput
 from pymatgen.io.smartio import read_structure
@@ -71,7 +72,9 @@ class VaspJob(Job, MSONable):
                 the INCAR, KPOINTS, POSCAR and POTCAR will be copied with a
                 ".orig" appended. Defaults to True.
             gzipped:
-                Whether to gzip the final output. Defaults to False.
+                Deprecated. Please use the Custodian class's gzipped_output
+                option instead. Whether to gzip the final output. Defaults to
+                False.
             default_vasp_input_set:
                 Species the default input set to use for directories that do
                 not contain full set of VASP input files. For example,
@@ -182,7 +185,9 @@ class VaspJob(Job, MSONable):
                     cmd[-1] += ".gamma"
 
         with open(self.output_file, 'w') as f:
-            return subprocess.Popen(cmd, stdout=f)
+            p = subprocess.Popen(cmd, stdout=f)
+
+        return p
 
     def postprocess(self):
         for f in VASP_OUTPUT_FILES + [self.output_file]:
